<template>
  <div class="md:hidden">
    <select
      id="selected-tab"
      class="w-full rounded-md border border-gray-900/10 bg-white py-1.5 pl-3 pr-10 text-left text-gray-900 focus:outline-none focus:ring-2 focus:ring-primary-500 sm:text-sm sm:leading-6"
      name="selected-tab"
      @input="redirect($event)"
    >
      <option
        v-for="(tab, key) in tabs"
        :key="tab.name"
        :selected="$snowflake.router.isCurrent(tab.to)"
        :value="key"
      >
        {{ tab.name }}
      </option>
    </select>
  </div>
  <div class="hidden md:mb-2 md:block">
    <div class="border-b border-gray-900/10">
      <nav class="-mb-px flex space-x-8">
        <RouterLink
          v-for="tab in tabs"
          :key="tab.name"
          :class="[$snowflake.router.isCurrent(tab.to) ? 'border-primary-400 text-primary-500' : 'border-transparent text-gray-500 hover:border-gray-900/10 hover:text-gray-700']"
          :to="tab.to"
          class="whitespace-nowrap border-b-2 px-1 py-4 text-sm font-medium"
        >
          {{ tab.name }}
        </RouterLink>
      </nav>
    </div>
  </div>
</template>

<script lang="ts" setup>
import useAuth from "@/js/contexts/auth/composables/useAuth";
import { Permission } from "@/js/contexts/shared/models/Permission";

const { t } = useI18n();
const router = useRouter();
const { hasPermission } = useAuth();

const tabs = computed(() =>
  [
    { name: t("app.admin.settings.general.title"), to: { name: "admin.settings.general" }, hasPermission: hasPermission(Permission.ADMIN_SETTINGS_GENERAL) },
    { name: t("app.admin.settings.links.title"), to: { name: "admin.settings.links" }, hasPermission: hasPermission(Permission.ADMIN_SETTINGS_LINKS) },
    { name: t("app.admin.settings.landing.title"), to: { name: "admin.settings.landing" }, hasPermission: hasPermission(Permission.ADMIN_SETTINGS_LANDING) },
    { name: t("app.admin.settings.seo.title"), to: { name: "admin.settings.seo" }, hasPermission: hasPermission(Permission.ADMIN_SETTINGS_SEO) },
    { name: t("app.admin.settings.appearance.title"), to: { name: "admin.settings.appearance" }, hasPermission: hasPermission(Permission.ADMIN_SETTINGS_APPEARANCE) },
    { name: t("app.admin.settings.authentication.title"), to: { name: "admin.settings.authentication" }, hasPermission: hasPermission(Permission.ADMIN_SETTINGS_AUTHENTICATION) },
    { name: t("app.admin.settings.outgoing_mail.title"), to: { name: "admin.settings.outgoing_mail" }, hasPermission: hasPermission(Permission.ADMIN_SETTINGS_OUTGOING_MAIL) },
  ].filter((item) => item.hasPermission),
);

const redirect = (event: Event) => {
  router.push(tabs.value[(event as Event & { target: { value: number } }).target.value]?.to);
};
</script>
